@@ -235,7 +235,7 @@ impl ApiError {
 }
 
 impl Fail for ApiError {
-    fn cause(&self) -> Option<&Fail> {
+    fn cause(&self) -> Option<&dyn Fail> {
         self.cause.as_ref().map(|boxed| &**boxed)
     }
 
