@@ -128,10 +128,10 @@ mod api_error;
 #[cfg(feature = "with_api_error")]
 pub use api_error::*;
 
-pub use http::{HttpTryFrom, StatusCode};
+pub use http::StatusCode;
 
 /// The recommended media type when serialized to JSON
-pub static PROBLEM_JSON_MEDIA_TYPE: &'static str = "application/problem+json";
+pub static PROBLEM_JSON_MEDIA_TYPE: &str = "application/problem+json";
 
 /// Description of a problem that can be returned by an HTTP API
 /// based on [RFC7807](https://tools.ietf.org/html/rfc7807)
@@ -235,7 +235,7 @@ impl HttpApiProblem {
         let status = status.into();
         HttpApiProblem {
             type_url: Some(format!("https://httpstatuses.com/{}", status.as_u16())),
-            status: Some(status.into()),
+            status: Some(status),
             title: status
                 .canonical_reason()
                 .unwrap_or("<unknown status code>")
@@ -265,7 +265,7 @@ impl HttpApiProblem {
         let status = status.into();
         HttpApiProblem {
             type_url: None,
-            status: Some(status.into()),
+            status: Some(status),
             title: status
                 .canonical_reason()
                 .unwrap_or("<unknown status code>")
@@ -315,7 +315,7 @@ impl HttpApiProblem {
     pub fn set_status<T: Into<StatusCode>>(self, status: T) -> HttpApiProblem {
         let status = status.into();
         let mut s = self;
-        s.status = Some(status.into());
+        s.status = Some(status);
         s
     }
 
@@ -622,7 +622,8 @@ impl<'r> ::rocket::response::Responder<'r> for HttpApiProblem {
 }
 
 mod custom_http_status_serialization {
-    use http::{HttpTryFrom, StatusCode};
+    use std::convert::TryFrom;
+    use http::StatusCode;
     use serde::{Deserialize, Deserializer, Serializer};
 
     pub fn serialize<S>(date: &Option<StatusCode>, s: S) -> Result<S::Ok, S::Error>
@@ -642,7 +643,7 @@ mod custom_http_status_serialization {
         let s: Option<u16> = Option::deserialize(deserializer)?;
         if let Some(numeric_status_code) = s {
             // If the status code numeral is invalid we somply have none...
-            let status_code = HttpTryFrom::try_from(numeric_status_code).ok();
+            let status_code = StatusCode::try_from(numeric_status_code).ok();
             return Ok(status_code);
         }
 
